#ifndef NT2_INCLUDE_FUNCTIONS_HI_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_HI_HPP_INCLUDED

#include <nt2/bitwise/include/functions/hi.hpp>

#endif
